openUri static method

Future<RarFile> openUri({
  1. required Uri uri,
})

Opens the RAR archive from the specified universal_io uri.

This method implements the Factory Method design pattern.

Returns a RarFile instance that can be used to read and extract files. Throws a RarException if the URI cannot be opened, has an invalid signature, or fails header parsing.

Implementation

static Future<RarFile> openUri({required Uri uri}) {
  return RarFileImpl.openUri(uri);
}