RarArchiveReader class
The entry-point class for accessing RAR archives.
This class implements the Factory Method design pattern, providing static methods to open a RAR archive and return a RarFile instance.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
String filePath) → Future< RarFile> -
Opens the RAR archive at the specified
filePath. -
openFile(
{required File file}) → Future< RarFile> -
Opens the RAR archive from the specified universal_io
file. -
openUri(
{required Uri uri}) → Future< RarFile> -
Opens the RAR archive from the specified universal_io
uri.