RarFileImpl class
Concrete infrastructure implementation of the RarFile interface.
This class parses the RAR5 block structure and extracts stored files in a random-access manner using RandomAccessFile. It implements the Facade design pattern to simplify interactions with the binary structure.
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
extractEntry(
{required RarArchiveEntry entry}) → Future< List< int> > -
Extracts the content of the specified
entryfrom the RAR archive.override -
findEntry(
{required String name}) → Future< RarArchiveEntry> -
Finds an archive entry by its exact name.
override
-
getArchiveEntries(
) → Future< List< RarArchiveEntry> > -
Returns a list of all entries present in the RAR archive.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
String filePath) → Future< RarFileImpl> -
Opens and parses the RAR archive at
filePath. -
openFile(
File file) → Future< RarFileImpl> -
Opens and parses the RAR archive at the specified
file. -
openUri(
Uri uri) → Future< RarFileImpl> -
Opens and parses the RAR archive at the specified
uri.